@@ -9,7 +9,7 @@ import scipy.stats
 from typing import Union, Tuple
 from sklearn.cluster import KMeans
 from sklearn import metrics
-from . import clusterizer as cls
+# from . import clusterizer as cls
 
 
 def hhi_1(tab) -> float:
@@ -229,8 +229,8 @@ def get_nb_misclassifieds_old(mat, grp_priors):
 
 
 def get_nb_misclassifieds(mat: Union[np.ndarray, pd.DataFrame],
-                          cltzr: cls.Clusterizer,
-                          ref_cltzr: cls.Clusterizer):
+                          cltzr,
+                          ref_cltzr):
     ngrps = cltzr.get_nbgroups()
     ref_ngrps = ref_cltzr.get_nbgroups()
     assert(ngrps == ref_ngrps)
@@ -239,7 +239,7 @@ def get_nb_misclassifieds(mat: Union[np.ndarray, pd.DataFrame],
     return get_clustering_mismatches(mat, grps, ref_grps)
 
 
-def get_avg_features_by_clusters(mat: Union[np.ndarray, pd.DataFrame], cltzr: cls.Clusterizer):
+def get_avg_features_by_clusters(mat: Union[np.ndarray, pd.DataFrame], cltzr):
     groups = cltzr.apply(mat)
     ngroups = len(set(groups))
     df_mat = pd.DataFrame(mat)
